==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Feuille de temps"
 ,"Feuilles de temps"

]
, "Account"
: "Compte"

, "Time Account (Number - Title)"
: "Compte de temps (nombre - titre)"

, "Billable"
: "Facturable"

, "Cleared in"
: "Acquitté"

, "Invoice"
: ""

, "Cleared"
: "Acquitté"

, "Date"
: "Date"

, "Start time"
: "Date de début"

, "End time"
: ""

, "Duration"
: "Durée"

, "Description"
: "Description"

, "Type"
: ""

, "Time Account closed"
: "Compte fermé"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: "Contrat"

, "Title"
: "Titre"

, "Number"
: "Numéro"

, "Price"
: ""

, "Status"
: "État"

, "Billed"
: "Facturé"

, "Cleared at"
: "Acquitté le"

, "Booking deadline"
: "Date limite de réservation"

, "Responsible"
: ""

, "Cost Center"
: "Centre de coût"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Compte de temps"
 ,"Comptes de temps"

]
, "Time Account - Status"
: "Comptes épargne-temps - État"

, "closed"
: "fermé"

, "open"
: "Ouvert"

, "Not a valid time"
: "Temps invalide"

, "Time Account - Billed"
: "Compte de temps - Facturé"

, "not yet billed"
: "pas encore facturé"

, "to bill"
: "à facturer"

, "billed"
: "facturé"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Acquitté"

, "Select Time Account..."
: "veuillez sélectionner un compte..."

, "Start"
: "Début"

, "not set"
: "non défini"

, "End"
: ""

, "Enter description..."
: "Veuillez saisir une description..."

, "Need for Clarification"
: ""

, "Failed"
: "Échec"

, "Could not save {0}."
: "Impossible de sauver {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "La date limite de réservation pour ce compte a été dépassée."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Réserver pour soi"

, "The grant to add Timesheets to this Timeaccount"
: "Le droit d'ajouter des feuilles de temps à ce compte"

, "View All"
: "Voir tout"

, "The grant to view Timesheets of other users"
: "Le droit de voir les feuilles de temps des autres utilisateurs"

, "Book All"
: "Réserver tout"

, "The grant to add Timesheets for other users"
: "Le droit d'ajouter des feuilles de temps pour les autres utilisateurs"

, "Manage Clearing"
: "Gérer les acquittements"

, "The grant to manage clearing of Timesheets"
: "Le droit de gérer l'effacement des feuilles de temps"

, "without contract"
: "sans contrat"

, "without responsible"
: ""

, "timeframe"
: "calendrier"

, "summary"
: "Résumé"

, "Total Timesheets"
: "Total (Feuilles de temps)"

, "Billable Timesheets"
: "Feuilles de temps à facturer"

, "Total Time"
: "Temps total"

, "Time of Billable Timesheets"
: "Date d'échéance des feuilles de temps"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exporter le tableau de suivi"

, "Export as ODS"
: "Exporter en ODS"

, "Export as CSV"
: "Exporter en CSV"

, "Export as ..."
: "Exporter au format..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Unité"

, "Unit Price"
: "Prix de l'unité"

, "Budget"
: "Budget"

, "Timesheets are billable"
: "Les feuilles de temps sont facturables"

, "Access"
: "Accès"

, "Permissions"
: "Permissions"

, "Show closed"
: "Afficher terminés"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Configuration de l'exportation des feuilles de temps au format ODS"

, "Use this configuration for the timesheet ODS export."
: "Utiliser cette configuration pour l'exportation des feuilles de temps au format ODS."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "défaut"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "aucun"

, "last week"
: "semaine dernière"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Gérer"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Ajouter, éditer et supprimer les comptes de temps (inclut les droits sur les tableaux de suivi)"

, "Add timeaccounts"
: "Ajouter un compte de temps"

, "Manage shared timeaccount favorites"
: "Gérer les comptes de temps partagés"

, "Create or update shared timeaccount favorites"
: "Créer ou ajouter des comptes de temps partagés"

, "Manage shared timesheet favorites"
: "Gérer les tables de pointages partagées"

, "Create or update shared timesheet favorites"
: "Ajouter ou modifier les tables de pointages partagées"

, "My Timesheets today"
: "Mon tableau d'ajourd'hui"

, "My Timesheets this week"
: "Mon tableau de la semaine"

, "My Timesheets last week"
: "Mon tableau de la semaine dernière"

, "My Timesheets this month"
: "Mon tableau du mois"

, "My Timesheets last month"
: "Mon tableau du mois dernier"

, "Timeaccounts to bill"
: "Prendre sur ces comptes de temps"

, "Timeaccounts not yet billed"
: "Comptes de temps pleins"

, "Timeaccounts already billed"
: "Comptes de temps utilisés"

, "Timetracker"
: "Planificateur"

, "Timesheet"
: "Feuille de temps"

, "Timeaccount"
: ""

, "Time Account"
: "Compte de temps"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "calendrier"

, "summary"
: "Résumé"

, "Total Timesheets"
: "Total (Feuilles de temps)"

, "Billable Timesheets"
: "Feuilles de temps à facturer"

, "Total Time"
: "Temps total"

, "Time of Billable Timesheets"
: "Date d'échéance des feuilles de temps"

, "Description"
: "Description"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exporter le tableau de suivi"

, "Export as ODS"
: "Exporter en ODS"

, "Export as CSV"
: "Exporter en CSV"

, "Export as ..."
: "Exporter au format..."

, "Timesheet, Timesheets"
: [
  "Feuille de temps"
 ,"Feuilles de temps"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Échec"

, "Could not save {0}."
: "Impossible de sauver {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "La date limite de réservation pour ce compte a été dépassée."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Contrat"

, "without contract"
: "sans contrat"

, "Add New Timeaccount"
: ""

, "Unit"
: "Unité"

, "Unit Price"
: "Prix de l'unité"

, "Factor"
: ""

, "Budget"
: "Budget"

, "Status"
: "État"

, "closed"
: "fermé"

, "open"
: "Ouvert"

, "Cleared In"
: "Acquitté"

, "Cleared at"
: "Acquitté le"

, "Cost Center"
: "Centre de coût"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Les feuilles de temps sont facturables"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Compte de temps"
 ,"Comptes de temps"

]
, "Number"
: "Numéro"

, "Title"
: "Titre"

, "Access"
: "Accès"

, "Permissions"
: "Permissions"

, "Time Account - Billed"
: "Compte de temps - Facturé"

, "not yet billed"
: "pas encore facturé"

, "to bill"
: "à facturer"

, "billed"
: "facturé"

, "Time Account - Status"
: "Comptes épargne-temps - État"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Réserver pour soi"

, "The grant to add Timesheets to this Timeaccount"
: "Le droit d'ajouter des feuilles de temps à ce compte"

, "View All"
: "Voir tout"

, "The grant to view Timesheets of other users"
: "Le droit de voir les feuilles de temps des autres utilisateurs"

, "Book All"
: "Réserver tout"

, "The grant to add Timesheets for other users"
: "Le droit d'ajouter des feuilles de temps pour les autres utilisateurs"

, "Manage Clearing"
: "Gérer les acquittements"

, "The grant to manage clearing of Timesheets"
: "Le droit de gérer l'effacement des feuilles de temps"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Afficher terminés"

, "Timesheets ODS export configuration"
: "Configuration de l'exportation des feuilles de temps au format ODS"

, "Use this configuration for the timesheet ODS export."
: "Utiliser cette configuration pour l'exportation des feuilles de temps au format ODS."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "défaut"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "aucun"

, "last week"
: "semaine dernière"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Acquitté"

, "Billed"
: "Facturé"

, "Booking deadline"
: "Date limite de réservation"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Compte"

, "Time Account (Number - Title)"
: "Compte de temps (nombre - titre)"

, "Billable"
: "Facturable"

, "Cleared"
: "Acquitté"

, "Date"
: "Date"

, "Start time"
: "Date de début"

, "End time"
: ""

, "Duration"
: "Durée"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Compte fermé"

, "Timetracker"
: "Planificateur"

, "Timeaccounts to bill"
: "Prendre sur ces comptes de temps"

, "Timeaccounts not yet billed"
: "Comptes de temps pleins"

, "Timeaccounts already billed"
: "Comptes de temps utilisés"

, "My Timesheets today"
: "Mon tableau d'ajourd'hui"

, "My Timesheets this week"
: "Mon tableau de la semaine"

, "My Timesheets last week"
: "Mon tableau de la semaine dernière"

, "My Timesheets this month"
: "Mon tableau du mois"

, "My Timesheets last month"
: "Mon tableau du mois dernier"

, "Manage timeaccounts"
: "Gérer"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Ajouter, éditer et supprimer les comptes de temps (inclut les droits sur les tableaux de suivi)"

, "Add timeaccounts"
: "Ajouter un compte de temps"

, "Manage shared timeaccount favorites"
: "Gérer les comptes de temps partagés"

, "Create or update shared timeaccount favorites"
: "Créer ou ajouter des comptes de temps partagés"

, "Manage shared timesheet favorites"
: "Gérer les tables de pointages partagées"

, "Create or update shared timesheet favorites"
: "Ajouter ou modifier les tables de pointages partagées"






, "Timesheet"
: "Feuille de temps"

, "Timeaccount"
: ""

, "Time Account"
: "Compte de temps"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
